@@ -14,7 +14,8 @@
 
 #include <QDebug>
 
-#include <kfts_fuzzy_match.h>
+#include <drawing_utils.h>
+#include <ktexteditor_utils.h>
 
 class LineNumberDelegate : public QStyledItemDelegate
 {
@@ -167,7 +168,7 @@ public:
             }
         }
 
-        kfts::paintItemViewText(painter, text, option, fmts);
+        Utils::paintItemViewText(painter, text, option, fmts);
 
         painter->restore();
     }
@@ -249,7 +250,7 @@ public:
             fmts.append({errIdx, 5, f});
         }
 
-        kfts::paintItemViewText(p, text, option, fmts);
+        Utils::paintItemViewText(p, text, option, fmts);
     }
 
 private:
@@ -281,8 +282,16 @@ AsmView::AsmView(QWidget *parent)
         c = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::BackgroundColor));
         palette.setColor(QPalette::Base, c);
         setPalette(palette);
+
+        auto model = static_cast<AsmViewModel *>(this->model());
+        if (!model) {
+            qWarning() << Q_FUNC_INFO << "Unexpected null model!";
+            return;
+        }
+        model->setFont(Utils::editorFont());
+
     };
-    updateColors();
+    QMetaObject::invokeMethod(this, updateColors, Qt::QueuedConnection);
     connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, updateColors);
 }
 
